from setuptools import setup

setup(name='probability_dnsd',
      version='1',
      description='Gaussian and Binomial distributions',
      packages=['probability_dnsd'],
      author_email= 'arghyadeepsaha17@gmail.com',
      install_requires=['matplotlib'],
      zip_safe=False)
